@@ -1,13 +1,19 @@
+from django import template
 from django.template import Context, loader
 from django.template.loader import render_to_string
 from django.core.urlresolvers import reverse
 
+class NotaDuckError(BaseException):
+	def __init__(self,value):
+		self.value = value
+
+	def render(self):
+		print "bar is not actually a bar. [ {0} ]".format(self.value)
 
 NAVIGATIONBARS = {}
 
 class NavigationManager:
 
-
 	def __init__(self):
 		pass
 
@@ -35,6 +41,8 @@ class NavigationManager:
 	def add_to_bar(self, name=None, buttons=None):
 		try :
 			bar = self.get_bar(name = name)
+			if not hasattr(bar, "add_buttons"):
+				raise NotaDuckError, "Returned bar was not actually a bar. :>"
 		except :
 			raise BaseException, "Bar %s not found" % name
 			return None
@@ -56,8 +64,13 @@ class NavigationManager:
 				global_bars.append(bar)
 		return global_bars
 
-class NavigationList :
 
+
+
+class NavigationList :
+	"""
+		A bar of buttons
+	"""
 	def __init__(self, parent=None, name=None, attributes=None, buttons=None, is_global=False):
 		self._name = name
 		self._buttons = []
@@ -88,24 +101,8 @@ class NavigationList :
 		return self._is_global
 
 	def add_button(self, button):
-		#print "Adding button : '%s' to bar '%s'" % (button['label'], self._name)
-		if not isinstance(button, dict):
-			raise BaseException, "button data needs to be a dictionary."
-		else :
-			if not 'url' in button.keys() :
-				try :
-					viewname = button['viewname']
-					urlconf = button['urlconf']
-					if 'args' in button.keys():
-						args = button['args']
-					else:
-						args = None
-				except :
-					raise BaseException, "Missing data from button dictionary"
-
-				button['url'] = reverse( viewname, urlconf = urlconf, args= args )
-
-			self._buttons.append(button)
+		#TODO: Render button html here, looking for children and rendering those too
+			self._buttons.append( render_button(button) )
 
 	def add_buttons(self, buttons=None):
 		if buttons :
@@ -133,3 +130,30 @@ class NavigationList :
 
 		return buttons
 
+def render_button( button ):
+
+	if not isinstance(button, dict):
+		raise BaseException, "button data needs to be a dictionary."
+
+	else :
+		if not 'url' in button.keys() :
+			try :
+				viewname = button['viewname']
+				urlconf = button['urlconf']
+				if 'args' in button.keys():
+					args = button['args']
+				else:
+					args = None
+			except :
+				raise BaseException, "Missing data from button dictionary"
+
+			button['url'] = reverse( viewname, urlconf = urlconf, args= args )
+
+		if button.has_key("children") and isinstance(button["children"],list) :
+			children = []
+			for child in button["children"] :
+				children.append( render_button(child) )
+			button['sub'] = children
+
+	return button
+
